@@ -38,13 +38,19 @@ class PostsRSS(Feed):
         else:
             self._public = not page.login_required
         if self._public:
+            settings.use_editable()
             if page is not None:
-                self.title = page.title
-                self.description = strip_tags(page.description)
+                self._title = "%s | %s" % (page.title, settings.SITE_TITLE)
+                self._description = strip_tags(page.description)
             else:
-                settings.use_editable()
-                self.title = settings.SITE_TITLE
-                self.description = settings.SITE_TAGLINE
+                self._title = settings.SITE_TITLE
+                self._description = settings.SITE_TAGLINE
+
+    def title(self):
+        return self._title
+
+    def description(self):
+        return self._description
 
     def link(self):
         return reverse("blog_post_feed", kwargs={"format": "rss"})
@@ -97,7 +103,7 @@ class PostsAtom(PostsRSS):
     feed_type = Atom1Feed
 
     def subtitle(self):
-        return self.description
+        return self.description()
 
     def link(self):
         return reverse("blog_post_feed", kwargs={"format": "atom"})
