@@ -32,7 +32,11 @@ urlpatterns = patterns("mezzanine.blog.views",
         "blog_post_list", name="blog_post_list_year"),
     url("^%s(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d{1,2})/"
         "(?P<slug>.*)%s$" % _slashes,
-        "blog_post_detail", name="blog_post_detail_date"),
+        "blog_post_detail", name="blog_post_detail_day"),
+    url("^%s(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<slug>.*)%s$" % _slashes,
+        "blog_post_detail", name="blog_post_detail_month"),
+    url("^%s(?P<year>\d{4})/(?P<slug>.*)%s$" % _slashes,
+        "blog_post_detail", name="blog_post_detail_year"),
     url("^%s(?P<slug>.*)%s$" % _slashes, "blog_post_detail",
         name="blog_post_detail"),
     url("^%s$" % _slashes[1], "blog_post_list", name="blog_post_list"),
