@@ -151,8 +151,8 @@ register_setting(
 register_setting(
     name="GOOGLE_ANALYTICS_ID",
     label=_("Google Analytics ID"),
-    editable=True,
     description=_("Google Analytics ID (http://www.google.com/analytics/)"),
+    editable=True,
     default="",
 )
 
@@ -170,6 +170,13 @@ register_setting(
     default=(),
 )
 
+register_setting(
+    name="INLINE_EDITING_ENABLED",
+    description=_("If ``True``, front-end inline editing will be enabled."),
+    editable=False,
+    default=True,
+)
+
 register_setting(
     name="JQUERY_FILENAME",
     label=_("Name of the jQuery file."),
