@@ -1,11 +1,14 @@
 
 from django.contrib import admin
 from django.contrib.auth import logout
+from django.contrib.redirects.models import Redirect
+from django.core.exceptions import MiddlewareNotUsed
 from django.core.urlresolvers import reverse
 from django.http import (HttpResponse, HttpResponseRedirect,
-                         HttpResponsePermanentRedirect)
+                         HttpResponsePermanentRedirect, HttpResponseGone)
 from django.utils.cache import get_max_age
 from django.template import Template, RequestContext
+from django.middleware.csrf import CsrfViewMiddleware, get_token
 
 from mezzanine.conf import settings
 from mezzanine.core.models import SitePermission
@@ -167,6 +170,11 @@ class FetchFromCacheMiddleware(object):
     Request phase for Mezzanine cache middleware. Return a response
     from cache if found, othwerwise mark the request for updating
     the cache in ``UpdateCacheMiddleware``.
+
+    If the response is served from cache and process_request returns a valid
+    response, Django will not execute the next middlewares, but we really
+    need ``CsrfViewMiddleware`` to run before ``UpdateCacheMiddleware`` to
+    make sure a valid csrf token exist.
     """
 
     def process_request(self, request):
@@ -177,6 +185,11 @@ class FetchFromCacheMiddleware(object):
             if response is None:
                 request._update_cache = True
             else:
+                csrf_mw_name = "django.middleware.csrf.CsrfViewMiddleware"
+                if csrf_mw_name in settings.MIDDLEWARE_CLASSES:
+                    csrf_mw = CsrfViewMiddleware()
+                    csrf_mw.process_view(request, lambda x: None, None, None)
+                    get_token(request)
                 return HttpResponse(response)
 
 
@@ -203,3 +216,31 @@ class SSLRedirectMiddleware(object):
                     return HttpResponseRedirect("https://%s" % url)
             elif request.is_secure() and settings.SSL_FORCED_PREFIXES_ONLY:
                 return HttpResponseRedirect("http://%s" % url)
+
+
+class RedirectFallbackMiddleware(object):
+    """
+    Port of Django's ``RedirectFallbackMiddleware`` that uses
+    Mezzanine's approach for determining the current site.
+    """
+
+    def __init__(self):
+        if "django.contrib.redirects" not in settings.INSTALLED_APPS:
+            raise MiddlewareNotUsed
+
+    def process_response(self, request, response):
+        if response.status_code == 404:
+            lookup = {
+                "site_id": current_site_id(),
+                "old_path": request.get_full_path(),
+            }
+            try:
+                redirect = Redirect.objects.get(**lookup)
+            except Redirect.DoesNotExist:
+                pass
+            else:
+                if not redirect.new_path:
+                    response = HttpResponseGone()
+                else:
+                    response = HttpResponseRedirect(redirect.new_path)
+        return response
